<?php

return [
    'languagePublished' => 'Language pack published successfully.',
    'allLanguagePublished' => 'All language packs published successfully.',
    'moduleActivatedNote' => 'You have activated the Language Pack module. Please publish your languages from :link.',
];
