<?php

return [
    'publishAll' => 'Publish All',
    'publish' => 'Publish',
    'republish' => 'Republish',
    'publishConfirm' => 'Are you sure you want to publish this language pack?',
    'republishConfirm' => 'Are you sure you want to republish this language pack? All your changes will be lost. This action cannot be undone.',
    'publishAllConfirm' => 'Are you sure you want to publish all language packs? This will overwrite all your changes in language files.',
    'publishAllButtonPopover' => 'Publish All Below Languages',
    'publishButtonPopover' => 'Publish :language Language',
    'republishButtonPopover' => 'Republish :language Language',
];
